stage_table(df, table_name)
stage_table.RdWrite a dataframe as a table within the Elmer.stg schema
Usage
stage_table(df, table_name = deparse(substitute(df)))stage_table.RdWrite a dataframe as a table within the Elmer.stg schema
stage_table(df, table_name = deparse(substitute(df)))